# -*- coding: utf-8 -*-

"""Top-level package for TkMVC."""

from tkmvc.tkmvc import App
from tkmvc.views.bank import Bank
from tkmvc.controllers.controller import Controller

__author__ = """Dan Huckson"""
__email__ = 'danhuckson@hotmail.com'
__version__ = '0.1.15'
